@@ -7,9 +7,7 @@
  * ABSTRACT: terminal input
  */
 
-#include "kernel/structs.h"
-
-extern char    prompt_char; /*1 either '>' or '.'*/
+EXTERN_VAR char    prompt_char; /*1 either '>' or '.'*/
 
 #ifdef __cplusplus
 
